@@ -47,6 +47,7 @@ __all__ = [
     'intersperse',
     'islice_extended',
     'iterate',
+    'ichunked',
     'last',
     'locate',
     'lstrip',
@@ -54,6 +55,7 @@ __all__ = [
     'map_reduce',
     'numeric_range',
     'one',
+    'only',
     'padded',
     'partitions',
     'peekable',
@@ -503,9 +505,8 @@ def one(iterable, too_short=None, too_long=None):
         RuntimeError
 
     Note that :func:`one` attempts to advance *iterable* twice to ensure there
-    is only one item. If there is more than one, both items will be discarded.
-    See :func:`spy` or :func:`peekable` to check iterable contents less
-    destructively.
+    is only one item. See :func:`spy` or :func:`peekable` to check iterable
+    contents less destructively.
 
     """
     it = iter(iterable)
@@ -1565,6 +1566,19 @@ def numeric_range(*args):
     Be aware of the limitations of floating point numbers; the representation
     of the yielded numbers may be surprising.
 
+    ``datetime.datetime`` objects can be used for *start* and *stop*, if *step*
+    is a ``datetime.timedelta`` object:
+
+        >>> import datetime
+        >>> start = datetime.datetime(2019, 1, 1)
+        >>> stop = datetime.datetime(2019, 1, 3)
+        >>> step = datetime.timedelta(days=1)
+        >>> items = numeric_range(start, stop, step)
+        >>> next(items)
+        datetime.datetime(2019, 1, 1, 0, 0)
+        >>> next(items)
+        datetime.datetime(2019, 1, 2, 0, 0)
+
     """
     argc = len(args)
     if argc == 1:
@@ -1581,9 +1595,10 @@ def numeric_range(*args):
         raise TypeError(err_msg.format(argc))
 
     values = (start + (step * n) for n in count())
-    if step > 0:
+    zero = type(step)(0)
+    if step > zero:
         return takewhile(partial(gt, stop), values)
-    elif step < 0:
+    elif step < zero:
         return takewhile(partial(lt, stop), values)
     else:
         raise ValueError('numeric_range arg 3 must not be zero')
@@ -1885,7 +1900,7 @@ def consecutive_groups(iterable, ordering=lambda x: x):
         yield map(itemgetter(1), g)
 
 
-def difference(iterable, func=sub):
+def difference(iterable, func=sub, *, initial=None):
     """By default, compute the first difference of *iterable* using
     :func:`operator.sub`.
 
@@ -1893,7 +1908,7 @@ def difference(iterable, func=sub):
         >>> list(difference(iterable))
         [0, 1, 2, 3, 4]
 
-    This is the opposite of :func:`accumulate`'s default behavior:
+    This is the opposite of :func:`itertools.accumulate`'s default behavior:
 
         >>> from itertools import accumulate
         >>> iterable = [0, 1, 2, 3, 4]
@@ -1914,13 +1929,26 @@ def difference(iterable, func=sub):
         >>> list(difference(iterable, func))
         [1, 2, 3, 4, 5]
 
+    Since Python 3.8, :func:`itertools.accumulate` can be supplied with an
+    *initial* keyword argument. If :func:`difference` is called with *initial*
+    set to something other than ``None``, it will skip the first element when
+    computing successive differences.
+
+        >>> iterable = [100, 101, 103, 106]  # accumate([1, 2, 3], initial=100)
+        >>> list(difference(iterable, initial=100))
+        [1, 2, 3]
+
     """
     a, b = tee(iterable)
     try:
-        item = next(b)
+        first = [next(b)]
     except StopIteration:
         return iter([])
-    return chain([item], map(lambda x: func(x[1], x[0]), zip(a, b)))
+
+    if initial is not None:
+        first = []
+
+    return chain(first, map(lambda x: func(x[1], x[0]), zip(a, b)))
 
 
 class SequenceView(Sequence):
@@ -2401,3 +2429,76 @@ def time_limited(limit_seconds, iterable):
         if monotonic() - start_time > limit_seconds:
             break
         yield item
+
+
+def only(iterable, default=None, too_long=None):
+    """If *iterable* has only one item, return it.
+    If it has zero items, return *default*.
+    If it has more than one item, raise the exception given by *too_long*,
+    which is ``ValueError`` by default.
+
+    >>> only([], default='missing')
+    'missing'
+    >>> only([1])
+    1
+    >>> only([1, 2])  # doctest: +IGNORE_EXCEPTION_DETAIL
+    Traceback (most recent call last):
+    ...
+    ValueError: too many items in iterable (expected 1)'
+    >>> only([1, 2], too_long=TypeError)  # doctest: +IGNORE_EXCEPTION_DETAIL
+    Traceback (most recent call last):
+    ...
+    TypeError
+
+    Note that :func:`only` attempts to advance *iterable* twice to ensure there
+    is only one item.  See :func:`spy` or :func:`peekable` to check
+    iterable contents less destructively.
+    """
+    it = iter(iterable)
+    value = next(it, default)
+
+    try:
+        next(it)
+    except StopIteration:
+        pass
+    else:
+        raise too_long or ValueError('too many items in iterable (expected 1)')
+
+    return value
+
+
+def ichunked(iterable, n):
+    """Break *iterable* into sub-iterables with *n* elements each.
+    :func:`ichunked` is like :func:`chunked`, but it yields iterables
+    instead of lists.
+
+    If the sub-iterables are read in order, the elements of *iterable*
+    won't be stored in memory.
+    If they are read out of order, :func:`itertools.tee` is used to cache
+    elements as necessary.
+
+    >>> from itertools import count
+    >>> all_chunks = ichunked(count(), 4)
+    >>> c_1, c_2, c_3 = next(all_chunks), next(all_chunks), next(all_chunks)
+    >>> list(c_2)  # c_1's elements have been cached; c_3's haven't been
+    [4, 5, 6, 7]
+    >>> list(c_1)
+    [0, 1, 2, 3]
+    >>> list(c_3)
+    [8, 9, 10, 11]
+
+    """
+    source = iter(iterable)
+
+    while True:
+        # Check to see whether we're at the end of the source iterable
+        item = next(source, _marker)
+        if item is _marker:
+            return
+
+        # Clone the source and yield an n-length slice
+        source, it = tee(chain([item], source))
+        yield islice(it, n)
+
+        # Advance the source iterable
+        consume(source, n)
