@@ -1,4 +1,5 @@
 from collections import OrderedDict
+from datetime import datetime, timedelta
 from decimal import Decimal
 from doctest import DocTestSuite
 from fractions import Fraction
@@ -16,8 +17,9 @@ from itertools import (
     repeat,
 )
 from operator import add, mul, itemgetter
+from sys import version_info
 from time import sleep
-from unittest import TestCase
+from unittest import skipIf, TestCase
 
 import more_itertools as mi
 
@@ -1791,6 +1793,18 @@ class NumericRangeTests(TestCase):
             ((1.0, 0.0), []),
             ((Fraction(2, 1),), [Fraction(0, 1), Fraction(1, 1)]),
             ((Decimal('2.0'),), [Decimal('0.0'), Decimal('1.0')]),
+            (
+                (
+                    datetime(2019, 3, 29, 12, 34, 56),
+                    datetime(2019, 3, 29, 12, 37, 55),
+                    timedelta(minutes=1)
+                ),
+                [
+                    datetime(2019, 3, 29, 12, 34, 56),
+                    datetime(2019, 3, 29, 12, 35, 56),
+                    datetime(2019, 3, 29, 12, 36, 56),
+                ]
+            ),
         ]:
             actual = list(mi.numeric_range(*args))
             self.assertEqual(actual, expected)
@@ -1805,9 +1819,16 @@ class NumericRangeTests(TestCase):
         )
 
     def test_zero_step(self):
-        self.assertRaises(
-            ValueError, lambda: list(mi.numeric_range(1, 2, 0))
-        )
+        for args in [
+            (1, 2, 0),
+            (
+                datetime(2019, 3, 29, 12, 34, 56),
+                datetime(2019, 3, 29, 12, 37, 55),
+                timedelta(minutes=0)
+            ),
+        ]:
+            with self.assertRaises(ValueError):
+                list(mi.numeric_range(*args))
 
 
 class CountCycleTests(TestCase):
@@ -1977,6 +1998,13 @@ class DifferenceTest(TestCase):
     def test_empty(self):
         self.assertEqual(list(mi.difference([])), [])
 
+    @skipIf(version_info[:2] < (3, 8), 'accumulate with initial needs 3.8+')
+    def test_initial(self):
+        original = list(range(100))
+        accumulated = accumulate(original, initial=100)
+        actual = list(mi.difference(accumulated, initial=100))
+        self.assertEqual(actual, original)
+
 
 class SeekableTest(TestCase):
     def test_exhaustion_reset(self):
@@ -2450,3 +2478,66 @@ class TimeLimitedTests(TestCase):
     def test_invalid_limit(self):
         with self.assertRaises(ValueError):
             list(mi.time_limited(-0.1, count()))
+
+
+class OnlyTests(TestCase):
+    def test_defaults(self):
+        self.assertEqual(mi.only([]), None)
+        self.assertEqual(mi.only([1]), 1)
+        self.assertRaises(ValueError, lambda: mi.only([1, 2]))
+
+    def test_custom_value(self):
+        self.assertEqual(mi.only([], default='!'), '!')
+        self.assertEqual(mi.only([1], default='!'), 1)
+        self.assertRaises(ValueError, lambda: mi.only([1, 2], default='!'))
+
+    def test_custom_exception(self):
+        self.assertEqual(mi.only([], too_long=RuntimeError), None)
+        self.assertEqual(mi.only([1], too_long=RuntimeError), 1)
+        self.assertRaises(
+            RuntimeError, lambda: mi.only([1, 2], too_long=RuntimeError)
+        )
+
+
+class IchunkedTests(TestCase):
+    def test_even(self):
+        iterable = (str(x) for x in range(10))
+        actual = [''.join(c) for c in mi.ichunked(iterable, 5)]
+        expected = ['01234', '56789']
+        self.assertEqual(actual, expected)
+
+    def test_odd(self):
+        iterable = (str(x) for x in range(10))
+        actual = [''.join(c) for c in mi.ichunked(iterable, 4)]
+        expected = ['0123', '4567', '89']
+        self.assertEqual(actual, expected)
+
+    def test_zero(self):
+        iterable = []
+        actual = [list(c) for c in mi.ichunked(iterable, 0)]
+        expected = []
+        self.assertEqual(actual, expected)
+
+    def test_negative(self):
+        iterable = count()
+        with self.assertRaises(ValueError):
+            [list(c) for c in mi.ichunked(iterable, -1)]
+
+    def test_out_of_order(self):
+        iterable = map(str, count())
+        it = mi.ichunked(iterable, 4)
+        chunk_1 = next(it)
+        chunk_2 = next(it)
+        self.assertEqual(''.join(chunk_2), '4567')
+        self.assertEqual(''.join(chunk_1), '0123')
+
+    def test_laziness(self):
+        def gen():
+            yield 0
+            raise RuntimeError
+            yield from count(1)
+
+        it = mi.ichunked(gen(), 4)
+        chunk = next(it)
+        self.assertEqual(next(chunk), 0)
+        self.assertRaises(RuntimeError, next, it)
